==> gt_sat_api-1.3.0-py3-none-any.whl: gt_sat_api/models/dte.py <==
from dataclasses import dataclass
from datetime import datetime
from typing import Dict, List, Optional

from .complemento import Complemento
from .emisor import Emisor
from .frase import Frase
from .item import Item
from .receptor import Receptor
from .total_impuesto import TotalImpuesto


@dataclass
class DTE:
    """Agrupa la estructura para un DTE."""

    clase_documento: str
    codigo_moneda: str
    fecha_hora_emision: datetime
    tipo: str
    emisor: Emisor
    receptor: Receptor
    frases: List[Frase]
    items: List[Item]
    complementos: Optional[List[Complemento]] = None

    @property
    def total_impuestos(self) -> List[TotalImpuesto]:
        """Generate sum of monto_impuesto of Impuestos gropued by NombreCorto

        Returns:
            List[TotalImpuesto]
        """
        impuestos = (impuesto for item in self.items for impuesto in item.impuestos)
        _total_impuestos_dict: Dict[str, float] = {}
        for impuesto in impuestos:
            _total_impuestos_dict[impuesto.NombreCorto] = (
                _total_impuestos_dict.get(impuesto.NombreCorto, 0) + impuesto.monto_impuesto
            )
        _total_impuestos = [
            TotalImpuesto(nombre, monto) for nombre, monto in _total_impuestos_dict.items()
        ]
        return _total_impuestos

    @property
    def gran_total(self) -> float:
        """Get sum of total of the items

        Returns:
            float
        """
        _gran_total = sum([item.total for item in self.items])
        return _gran_total

==> gt_sat_api-1.4.1-py3-none-any.whl: gt_sat_api/models/dte.py <==
from dataclasses import dataclass
from datetime import datetime
from typing import Dict, List, Optional

from .complemento import Complemento
from .emisor import Emisor
from .frase import Frase
from .item import Item
from .receptor import Receptor
from .total_impuesto import TotalImpuesto


@dataclass
class DTE:
    """Agrupa la estructura para un DTE."""

    clase_documento: str
    codigo_moneda: str
    fecha_hora_emision: datetime
    tipo: str
    emisor: Emisor
    receptor: Receptor
    frases: List[Frase]
    items: List[Item]
    complementos: Optional[List[Complemento]] = None

    @property
    def total_impuestos(self) -> List[TotalImpuesto]:
        """Generate sum of monto_impuesto of Impuestos gropued by NombreCorto

        Returns:
            List[TotalImpuesto]
        """
        impuestos = (impuesto for item in self.items for impuesto in item.impuestos)
        _total_impuestos_dict: Dict[str, float] = {}
        for impuesto in impuestos:
            _total_impuestos_dict[impuesto.nombre_corto] = (
                _total_impuestos_dict.get(impuesto.nombre_corto, 0) + impuesto.monto_impuesto
            )
        _total_impuestos = [
            TotalImpuesto(nombre, monto) for nombre, monto in _total_impuestos_dict.items()
        ]
        return _total_impuestos

    @property
    def gran_total(self) -> float:
        """Get sum of total of the items

        Returns:
            float
        """
        _gran_total = sum([item.total for item in self.items])
        return _gran_total
